/*

   Two custom classes which provide NoDoubleClick functionality

*/

//////////////////////////////////////////////////////////////////////

/*

	Filename:   NoDoubleClickButton.cc
   Version:    1.00
   Date:       2000 07 14

   For:        VdBase 7.x / Win9x

   Author:     Ronnie MacGregor
   Contact:    ronnie@high-lugtonridgeKILLSPAM.co.uk
	
   
   Revisions:
   **********
      None.
         
   Description:
   ************
      A custom PushButton for use where repeated fast clicking is
      required, producing a stream on onClick events.

      DoubleClicks are prevented after the firing of onGotFocus,
      and restored in the onLostFocus event.

      This means that an initial double click can sometimes squeeze
      through, but no more after that.

      The desired effect will not be seen if the speedbar property of
      the pushButton is set to true. If this is required, use the
      NoDoubleClick custom form method, which will provide this
      functionality for every control on the form.
       

   Dependancies:
   *************
      None.


   Acknowledgements:
   *****************
      None.
         
*/


class NoDoubleClickButton(parentObj) of PUSHBUTTON(parentObj) custom

   #ifndef UINT
      #define UINT  CUINT
   #endif
   #ifndef VOID
      #define VOID  CVOID
   #endif
   #ifndef BOOL
      #define BOOL  CLOGICAL
   #endif

   this.onGotFocus = class::KillDoubleClick
   this.onLostFocus = class::RestoreDoubleClick

   if type( "GetDoubleClickTime" ) # "FP"
      extern UINT GetDoubleClickTime(VOID) user32
   endif

   if type( "SetDoubleClickTime" ) # "FP"
      extern BOOL SetDoubleClickTime(UINT) user32
   endif

   function KillDoubleClick()
      this.OldDoubleClickTime = GetDoubleClickTime()
      SetDoubleClickTime(10)
      return

   function RestoreDoubleClick()
      SetDoubleClickTime(this.OldDoubleClickTime)
      return

endclass

//////////////////////////////////////////////////////////////////////

/*

	Filename:   NoDoubleClickForm.cc
   Version:    2.00
   Date:       2000 07 14

   For:        VdBase 7.x / Win9x

   Author:     Ronnie MacGregor
   Contact:    ronnie@high-lugtonridgeKILLSPAM.co.uk
	
   
   Revisions:
   **********
      2002 10 23
      onGotFocus and onLostFocus events moved to codeblocks to prevent scope
      problems when the derived form is closed.

         
   Description:
   ************
      A custom Form for use where repeated fast clicking is required, producing
      a stream on onClick events.

      This will affect all controls on the form. If this is not desirable, use
      individual custom NoDoubleClick buttons.

      DoubleClicks are prevented after the firing of onGotFocus, and restored
      in the onLostFocus event.

      This means that an initial double click which also gives focus to the
      form can sometimes squeeze through, but no more after that.
       

   Dependancies:
   *************
      None.


   Acknowledgements:
   *****************
      None.
         
*/


class NoDoubleClickForm of FORM custom


   #ifndef UINT
      #define UINT  CUINT
   #endif
   #ifndef VOID
      #define VOID  CVOID
   #endif
   #ifndef BOOL
      #define BOOL  CLOGICAL
   #endif

   if type( "GetDoubleClickTime" ) # "FP"
      extern UINT GetDoubleClickTime(VOID) user32
   endif

   if type( "SetDoubleClickTime" ) # "FP"
      extern BOOL SetDoubleClickTime(UINT) user32
   endif

  
   // Store the system doubleCLick time
   this.OldDoubleClickTime = GetDoubleClickTime()

   this.onGotFocus = {; SetDoubleClickTime(10)}

   this.onLostFocus = {; SetDoubleClickTime(this.OldDoubleClickTime)}


endclass

//////////////////////////////////////////////////////////////////////

// eof
